@@ -40,7 +40,7 @@ around CLI => sub ( $orig, $self ) {
 };
 
 sub _build_selenium_ver ($self) {
-    return $self->cfg->{SELENIUM}->{SELENIUM_VER} // $ENV->get_dist('pcore-selenium')->cfg->{SELENIUM}->{SELENIUM_VER};
+    return $self->cfg->{SELENIUM}->{SELENIUM_VER} // $ENV->dist('Pcore-Selenium')->cfg->{SELENIUM}->{SELENIUM_VER};
 }
 
 sub _build_selenium_uri ($self) {
@@ -50,7 +50,7 @@ sub _build_selenium_uri ($self) {
 }
 
 sub _build_ff_ver ($self) {
-    return $self->cfg->{SELENIUM}->{FF_VER} // $ENV->get_dist('pcore-selenium')->cfg->{SELENIUM}->{FF_VER};
+    return $self->cfg->{SELENIUM}->{FF_VER} // $ENV->dist('Pcore-Selenium')->cfg->{SELENIUM}->{FF_VER};
 }
 
 sub _build_alien_bin_path ($self) {
