@@ -1,6 +1,6 @@
 package Pcore::Handle::Selenium;
 
-use Pcore qw[-class -autoload];
+use Pcore -class, -autoload;
 use Archive::Zip qw[];
 use Selenium::Remote::Driver qw[];
 use Selenium::Remote::WebElement qw[];
@@ -195,15 +195,14 @@ sub _get_firefox_profile {
     return P->data->to_b64($profile_zip);
 }
 
-sub autoload {
-    my $self   = shift;
-    my $method = shift;
+sub _AUTOLOAD ( $self, $method, @ ) {
+    return <<"PERL";
+        sub {
+            my \$self = shift;
 
-    return sub {
-        my $self = shift;
-
-        return $self->h->$method(@_);
-    };
+            return \$self->h->$method(\@_);
+        };
+PERL
 }
 
 sub ping {
@@ -307,6 +306,16 @@ sub find_child_elements_local {
 }
 
 1;
+## -----SOURCE FILTER LOG BEGIN-----
+##
+## PerlCritic profile "pcore-script" policy violations:
+## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
+## │ Sev. │ Lines                │ Policy                                                                                                         │
+## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
+## │    3 │ 198                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_AUTOLOAD' declared but not used    │
+## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+##
+## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
